@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="it">
 <context>
     <name>CMainWindow</name>
     <message>
@@ -189,7 +191,7 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
     </message>
     <message>
         <source>Maximum resolution:</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -260,6 +262,14 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
         <source>None</source>
         <translation>No</translation>
     </message>
+    <message>
+        <source>mp4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>filterPreviewButton</name>
@@ -342,4 +352,4 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
         <translation type="vanished">Interrompi video</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
